pub enum AuthError {
BackendNotApplicable(String),
NotEnrolled(String),
AgentUnavailable(String),
UnsupportedKeyType(String),
UnwrapFailed,
InvalidBlob(String),
NoEligibleKey,
AgentProtocolError(String),
Io(Error),
}Expand description
Errors from authentication backends.
Does not implement Clone because the Io variant wraps std::io::Error
which is not Clone. If clonability is needed for IPC forwarding, the
error should be converted to a string representation first.
Variants
BackendNotApplicable(String)
NotEnrolled(String)
UnsupportedKeyType(String)
UnwrapFailed
InvalidBlob(String)
NoEligibleKey
AgentProtocolError(String)
Io(Error)