pub enum FactorContribution {
CompleteMasterKey,
FactorPiece,
}Expand description
Which piece of the unlock this backend is providing.
Variants
CompleteMasterKey
This backend provides a complete master key (unwrapped independently).
Used in Any and Policy modes.
FactorPiece
This backend provides a factor piece for combined derivation.
Used in All mode where the master key is HKDF’d from all pieces.